Karbor Specs
============

This section contains detailed specification documents for
different features inside Karbor.

Contents:

.. toctree::
    :maxdepth: 3

    api-service
    bank-plugin-lease
    pluggable_protection_provider

Spec Template
-------------
.. toctree::
    :maxdepth: 3

    skeleton
    template


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
